@@ -22,13 +22,13 @@ class Menu():
         self.result = result
 
     def show(self):
-        print(f"{Colour.bracketsymbol}[{Colour.plussymbol}+{Colour.bracketsymbol}]{Colour.Yellow} {self.title}\t",end="")
+        print(f"{Colour.bracketsymbol}[{Colour.plussymbol}+{Colour.bracketsymbol}]{Colour.Yellow} {self.title}{' '*7}",end="")
         if type(self.options) == type([]):
-            for index, option in enumerate(self.options):
-                print(f"{Colour.Yellow}[{index+1}] {option}\t",end="")
+            for index, option in enumerate(self.options, 1):
+                print(f"{Colour.Yellow}[{index}] {option}{' '*7}",end="")
             print(f"{Colour.Reset}\n")
         elif type(self.options) == type(""):
-            print(f"{Colour.Yellow}[1] {self.options}{Colour.Reset}\n",end="")
+            print(f"{Colour.Yellow}[1] {self.options}{Colour.Reset}")
 
         self.value = getinput(self.title, self.options, self.result)
 
@@ -40,7 +40,6 @@ class Menu():
         if result != None:
             self.result = result
 
-
 class List():
     def __init__(self, title="List",options=[],result='index'):
         self.title = title
@@ -87,3 +86,7 @@ def getinput(title, options, result):
 # Displays text in a nice colourful format
 def display(text):
     print(f"{Colour.bracketsymbol}[{Colour.plussymbol}+{Colour.bracketsymbol}] {Colour.Reset}{text}\n")
+
+
+a = Menu(options=["11","2gsg2", "33dsfs", "4$sfd"])
+a.show()
